==> fnss-1.0.1.tgz: package/src/provider.js <==
/**
 * Copyright (c) 2017 Chris Baker <mail.chris.baker@gmail.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */

'use strict';

import React from 'react';
import PropTypes from 'prop-types';
import Context from './context';

export default class StyleSheetProvider extends React.Component {
  constructor(props) {
    super(props);
    this.stylesheet = new Context(props);
  }

  componentWillReceiveProps(props) {
    this.stylesheet.publish(props);
  }

  getChildContext() {
    return {
      stylesheet: this.stylesheet
    };
  }

  render() {
    return this.props.children;
  }
}

StyleSheetProvider.displayName = 'StyleSheetProvider';

StyleSheetProvider.propTypes = {
  children: PropTypes.node
};

StyleSheetProvider.defaultProps = {
  children: null
};

StyleSheetProvider.childContextTypes = {
  stylesheet: PropTypes.object.isRequired
};

==> fnss-1.2.1.tgz: package/src/provider.js <==
/**
 * Copyright (c) 2017 Chris Baker <mail.chris.baker@gmail.com>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */

'use strict';

import React from 'react';
import PropTypes from 'prop-types';
import Context from './context';

const sanitize = ({ children, ...props }) => props;

export default class StyleSheetProvider extends React.PureComponent {
  constructor(props) {
    super(props);

    this.stylesheet = new Context(sanitize(props));
  }

  componentWillReceiveProps(props) {
    this.stylesheet.publish(sanitize(props));
  }

  getChildContext() {
    return {
      stylesheet: this.stylesheet
    };
  }

  render() {
    return this.props.children;
  }
}

StyleSheetProvider.displayName = 'StyleSheetProvider';

StyleSheetProvider.propTypes = {
  children: PropTypes.node
};

StyleSheetProvider.defaultProps = {
  children: null
};

StyleSheetProvider.childContextTypes = {
  stylesheet: PropTypes.object.isRequired
};
